Changelog
=========

0.0.4
-----
#. Use `exists` optimisation.
#. Force commit on every execution of method since settings may specify a transaction managed database layer.
#. Prevent redundant calls to save().
#. Support direct assignment of foreign key ids.


0.0.3 (2011-08-12)
------------------
#. Corrected manifest.

0.0.2 (2011-07-26)
------------------
#. Docs.

0.0.1
-----
#. Initial release.

